[**高度な設定**](./introduction.md) > **言語コード** _(現在)_

---

#### Google

ソース <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>、GPT-4oによって整理。

| 中国語ラベル | ラベル | `言語コード` |
| --- | --- | --- |
| アムハラ語 | Amharic | `am` |
| 阿拉伯语 | Arabic | `ar` |
| ベンガル語 | Bengali | `bn` |
| ボスニア語 | Bosnian | `bs` |
| ブルガリア語 | Bulgarian | `bg` |
| カタロニア語 | Catalan | `ca` |
| セブアノ語 | Cebuano | `ceb` |
| チチェワ語 | Chichewa | `ny` |
| 中国語 (簡体字) | Chinese (Simplified) | `zh-CN` |
| 中国語 (繁体字) | Chinese (Traditional) | `zh-TW` |
| コルシカ語 | Corsican | `co` |
| クロアチア語 | Croatian | `hr` |
| チェコ語 | Czech | `cs` |
| デンマーク語 | Danish | `da` |
| オランダ語 | Dutch | `nl` |
| 英語 | English | `en` |
| エスペラント語 | Esperanto | `eo` |
| エストニア語 | Estonian | `et` |
| フィリピン語 | Filipino | `tl` |
| フィンランド語 | Finnish | `fi` |
| フランス語 | French | `fr` |
| フリジア語 | Frisian | `fy` |
| ガリシア語 | Galician | `gl` |
| グルジア語 | Georgian | `ka` |
| ドイツ語 | German | `de` |
| ギリシャ語 | Greek | `el` |
| グジャラート語 | Gujarati | `gu` |
| ハイチ・クレオール語 | Haitian Creole | `ht` |
| ハウサ語 | Hausa | `ha` |
| ハワイ語 | Hawaiian | `haw` |
| ヘブライ語 | Hebrew | `he` |
| ヒンディー語 | Hindi | `hi` |
| モン語 | Hmong | `hmn` |
| ハンガリー語 | Hungarian | `hu` |
| アイスランド語 | Icelandic | `is` |
| イボ語 | Igbo | `ig` |
| インドネシア語 | Indonesian | `id` |
| アイルランド語 | Irish | `ga` |
| イタリア語 | Italian | `it` |
| 日本語 | Japanese | `ja` |
| ジャワ語 | Javanese | `jw` |
| カンナダ語 | Kannada | `kn` |
| カザフ語 | Kazakh | `kk` |
| クメール語 | Khmer | `km` |
| ルワンダ語 | Kinyarwanda | `rw` |
| 韓国語 | Korean | `ko` |
| クルド語 (クルマンジー) | Kurdish (Kurmanji) | `ku` |
| キルギス語 | Kyrgyz | `ky` |
| ラオ語 | Lao | `lo` |
| ラテン語 | Latin | `la` |
| ラトビア語 | Latvian | `lv` |
| リトアニア語 | Lithuanian | `lt` |
| ルクセンブルク語 | Luxembourgish | `lb` |
| マケドニア語 | Macedonian | `mk` |
| マダガスカル語 | Malagasy | `mg` |
| マレー語 | Malay | `ms` |
| マラヤーラム語 | Malayalam | `ml` |
| マルタ語 | Maltese | `mt` |
| マオリ語 | Maori | `mi` |
| マラーティー語 | Marathi | `mr` |
| モンゴル語 | Mongolian | `mn` |
| ミャンマー語 (ビルマ語) | Myanmar (Burmese) | `my` |
| ネパール語 | Nepali | `ne` |
| ノルウェー語 | Norwegian | `no` |
| パシュトー語 | Pashto | `ps` |
| ペルシャ語 | Persian | `fa` |
| ポーランド語 | Polish | `pl` |
| ポルトガル語 | Portuguese | `pt` |
| パンジャブ語 | Punjabi | `pa` |
| ルーマニア語 | Romanian | `ro` |
| ロシア語 | Russian | `ru` |
| サモア語 | Samoan | `sm` |
| スコットランド・ゲール語 | Scots Gaelic | `gd` |
| セルビア語 | Serbian | `sr` |
| セソト語 | Sesotho | `st` |
| ショナ語 | Shona | `sn` |
| シンド語 | Sindhi | `sd` |
| シンハラ語 | Sinhala | `si` |
| スロバキア語 | Slovak | `sk` |
| スロベニア語 | Slovenian | `sl` |
| ソマリ語 | Somali | `so` |
| スペイン語 | Spanish | `es` |
| スンダ語 | Sundanese | `su` |
| スワヒリ語 | Swahili | `sw` |
| スウェーデン語 | Swedish | `sv` |
| タジク語 | Tajik | `tg` |
| タミル語 | Tamil | `ta` |
| テルグ語 | Telugu | `te` |
| タイ語 | Thai | `th` |
| トルコ語 | Turkish | `tr` |
| ウクライナ語 | Ukrainian | `uk` |
| ウルドゥー語 | Urdu | `ur` |
| ウズベク語 | Uzbek | `uz` |
| ベトナム語 | Vietnamese | `vi` |
| ウェールズ語 | Welsh | `cy` |
| コーサ語 | Xhosa | `xh` |
| イディッシュ語 | Yiddish | `yi` |
| ヨルバ語 | Yoruba | `yo` |
| ズールー語 | Zulu | `zu` |
| ベンガル語 | Bengali | `bn` |
| 英語（イギリス） | English (UK) | `en-GB` |
| ポルトガル語（ブラジル） | Portuguese (Brazil) | `pt-BR` |
| ブルガリア語 | Bulgarian | `bg` |
| カタルーニャ語 | Catalan | `ca` |
| チェロキー語 | Cherokee | `chr` |
| クロアチア語 | Croatian | `hr` |
| チェコ語 | Czech | `cs` |
| デンマーク語 | Danish | `da` |
### 翻訳結果:

| オランダ語 | Dutch | `nl` |
| 英語（アメリカ） | English (US) | `en` |
| エストニア語 | Estonian | `et` |
| フィリピン語 | Filipino | `fil` |
| フィンランド語 | Finnish | `fi` |
| フランス語 | French | `fr` |
| 德语 | German | `de` |
| ギリシャ語 | Greek | `el` |
| グジャラート語 | Gujarati | `gu` |
| ヘブライ語 | Hebrew | `iw` |
| ヒンディー語 | Hindi | `hi` |
| ハンガリー語 | Hungarian | `hu` |
| アイスランド語 | Icelandic | `is` |
| インドネシア語 | Indonesian | `id` |
| イタリア語 | Italian | `it` |
| 日语 | Japanese | `ja` |
| カンナダ語 | Kannada | `kn` |
| 韓国語 | Korean | `ko` |
| ラトビア語 | Latvian | `lv` |
| リトアニア語 | Lithuanian | `lt` |
| マレー語 | Malay | `ms` |
| マラヤーラム語 | Malayalam | `ml` |
| マラーティー語 | Marathi | `mr` |
| ノルウェー語 | Norwegian | `no` |
| ポーランド語 | Polish | `pl` |
| ポルトガル語（ポルトガル） | Portuguese (Portugal) | `pt-PT` |
| ルーマニア語 | Romanian | `ro` |
| 俄語 | Russian | `ru` |
| セルビア語 | Serbian | `sr` |
| 日本語（日本） | Japanese (Japan) | `ja-JP` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 中文（香港） | Chinese (Hong Kong) | `zh-HK` |
| 中文（澳门） | Chinese (Macau) | `zh-MO` |
| 中文（新加坡） | Chinese (Singapore) | `zh-SG` |

[!NOTE]
The `zh-CN` is the default language code for Chinese. If you want to translate to other Chinese variants, you can specify the language code like `zh-TW` for Traditional Chinese (Taiwan).

[!WARNING]
The `zh-HK` and `zh-MO` are not fully supported by all translation services. Please check the [Documentation of Translation Services](#documentation-of-translation-services) for more details.

### 中国語の言語コード

| 中国語（中国） | Chinese (PRC) | `zh-CN` |
| 中国語（台湾） | Chinese (Taiwan) | `zh-TW` |
| 中国語（香港） | Chinese (Hong Kong) | `zh-HK` |
| 中国語（マカオ） | Chinese (Macau) | `zh-MO` |
| 中国語（シンガポール） | Chinese (Singapore) | `zh-SG` |

[!NOTE]
`zh-CN` は中国語のデフォルトの言語コードです。他の中国語のバリアントに翻訳したい場合は、`zh-TW`（台湾の繁体字中国語）のように言語コードを指定できます。

[!WARNING]
`zh-HK` と `zh-MO` はすべての翻訳サービスで完全にはサポートされていません。詳細については[翻訳サービスドキュメント](#翻訳サービスドキュメント)を確認してください。
| スロバキア語 | Slovak | `sk` |
| スロベニア語 | Slovenian | `sl` |
| スペイン語 | Spanish | `es` |
| スワヒリ語 | Swahili | `sw` |
| スウェーデン語 | Swedish | `sv` |
| タミル語 | Tamil | `ta` |
| テルグ語 | Telugu | `te` |
| タイ語 | Thai | `th` |
| 中国語（台湾） | Chinese (Taiwan) | `zh-TW` |
| トルコ語 | Turkish | `tr` |
| ウルドゥー語 | Urdu | `ur` |
| ウクライナ語 | Ukrainian | `uk` |
| ベトナム語 | Vietnamese | `vi` |
| ウェールズ語 | Welsh | `cy` |

#### DeepL

ソース <https://developers.deepl.com/docs/resources/supported-languages>、GPT-4oによって整理。

| 中国語ラベル | ラベル | `Language Code` | サポート |
| --- | --- | --- | --- |
| アラビア語 | Arabic | `AR` | `source`, `target` |
| ブルガリア語 | Bulgarian | `BG` | `source`, `target` |
| チェコ語 | Czech | `CS` | `source`, `target` |
| デンマーク語 | Danish | `DA` | `source`, `target` |
| ドイツ語 | German | `DE` | `source`, `target` |
| ギリシャ語 | Greek | `EL` | `source`, `target` |
| 英語 | English | `EN` | `source`, `target` |
| 英語（イギリス） | English (British) | `EN-GB` | `target` |
| 英語（アメリカ） | English (American) | `EN-US` | `target` |
| スペイン語 | Spanish | `ES` | `source`, `target` |
| エストニア語 | Estonian | `ET` | `source`, `target` |
| フィンランド語 | Finnish | `FI` | `source`, `target` |
| フランス語 | French | `FR` | `source`, `target` |
| ハンガリー語 | Hungarian | `HU` | `source`, `target` |
| インドネシア語 | Indonesian | `ID` | `source`, `target` |
| イタリア語 | Italian | `IT` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| 韓国語 | Korean | `KO` | `source`, `target` |
| リトアニア語 | Lithuanian | `LT` | `source`, `target` |
| ラトビア語 | Latvian | `LV` | `source`, `target` |
| ノルウェー・ブークモール語 | Norwegian Bokmål | `NB` | `source`, `target` |
| オランダ語 | Dutch | `NL` | `source`, `target` |
| ポーランド語 | Polish | `PL` | `source`, `target` |
| ポルトガル語 | Portuguese | `PT` | `source`, `target` |
| ポルトガル語（ブラジル） | Portuguese (Brazilian) | `PT-BR` | `target` |
| ポルトガル語（ヨーロッパ） | Portuguese (European) | `PT-PT` | `target` |
| ルーマニア語 | Romanian | `RO` | `source`, `target` |
| ロシア語 | Russian | `RU` | `source`, `target` |
| スロバキア語 | Slovak | `SK` | `source`, `target` |
| スロベニア語 | Slovenian | `SL` | `source`, `target` |
| スウェーデン語 | Swedish | `SV` | `source`, `target` |
| トルコ語 | Turkish | `TR` | `source`, `target` |
| ウクライナ語 | Ukrainian | `UK` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| 日本語 | Japanese | `JA` | `target` |
|--------------|----------------------|-----------|----------|---------|--------|----------|------|----------|
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` | 英語 | English | `EN` | `source` |
| 日本語 | Japanese | `JA` | `target` | ドイツ語 | German | `DE` | `target` |
| 韓国語 | Korean | `KO` | `target` | フランス語 | French | `FR` | `target` |
| スペイン語 | Spanish | `ES` | `target` | イタリア語 | Italian | `IT` | `target` |
| ポルトガル語 | Portuguese | `PT` | `target` | ロシア語 | Russian | `RU` | `target` |
| アラビア語 | Arabic | `AR` | `target` | ヒンディー語 | Hindi | `HI` | `target` |
| ベンガル語 | Bengali | `BN` | `target` | ウルドゥー語 | Urdu | `UR` | `target` |
| インドネシア語 | Indonesian | `ID` | `target` | タイ語 | Thai | `TH` | `target` |
| ベトナム語 | Vietnamese | `VI` | `target` | トルコ語 | Turkish | `TR` | `target` |
| ペルシャ語 | Persian | `FA` | `target` | ポーランド語 | Polish | `PL` | `target` |
| ウクライナ語 | Ukrainian | `UK` | `target` | ルーマニア語 | Romanian | `RO` | `target` |
| オランダ語 | Dutch | `NL` | `target` | スウェーデン語 | Swedish | `SV` | `target` |
| フィンランド語 | Finnish | `FI` | `target` | デンマーク語 | Danish | `DA` | `target` |
| ノルウェー語 | Norwegian | `NO` | `target` | チェコ語 | Czech | `CS` | `target` |
| ハンガリー語 | Hungarian | `HU` | `target` | ギリシャ語 | Greek | `EL` | `target` |
| ブルガリア語 | Bulgarian | `BG` | `target` | スロバキア語 | Slovak | `SK` | `target` |
| クロアチア語 | Croatian | `HR` | `target` | スロベニア語 | Slovenian | `SL` | `target` |
| リトアニア語 | Lithuanian | `LT` | `target` | ラトビア語 | Latvian | `LV` | `target` |
| エストニア語 | Estonian | `ET` | `target` | マルタ語 | Maltese | `MT` | `target` |
| アイルランド語 | Irish | `GA` | `target` | ウェールズ語 | Welsh | `CY` | `target` |
| バスク語 | Basque | `EU` | `target` | カタルーニャ語 | Catalan | `CA` | `target` |
| ガリシア語 | Galician | `GL` | `target` | アイスランド語 | Icelandic | `IS` | `target` |
| アルバニア語 | Albanian | `SQ` | `target` | マケドニア語 | Macedonian | `MK` | `target` |
| セルビア語 | Serbian | `SR` | `target` | ボスニア語 | Bosnian | `BS` | `target` |
| モンテネグロ語 | Montenegrin | `ME` | `target` | ベラルーシ語 | Belarusian | `BE` | `target` |
| カザフ語 | Kazakh | `KK` | `target` | ウズベク語 | Uzbek | `UZ` | `target` |
| キルギス語 | Kyrgyz | `KY` | `target` | タジク語 | Tajik | `TG` | `target` |
| トルクメン語 | Turkmen | `TK` | `target` | モンゴル語 | Mongolian | `MN` | `target` |
| チベット語 | Tibetan | `BO` | `target` | ウイグル語 | Uyghur | `UG` | `target` |
| クルド語 | Kurdish | `KU` | `target` | アムハラ語 | Amharic | `AM` | `target` |
| ネパール語 | Nepali | `NE` | `target` | シンハラ語 | Sinhala | `SI` | `target` |
| ビルマ語 | Burmese | `MY` | `target` | クメール語 | Khmer | `KM` | `target` |
| ラオス語 | Lao | `LO` | `target` | マレー語 | Malay | `MS` | `target` |
| スンダ語 | Sundanese | `SU` | `target` | ジャワ語 | Javanese | `JV` | `target` |
| タガログ語 | Tagalog | `TL` | `target` | ハワイ語 | Hawaiian | `HAW` | `target` |
| マオリ語 | Maori | `MI` | `target` | サモア語 | Samoan | `SM` | `target` |
| フィジー語 | Fijian | `FJ` | `target` | トンガ語 | Tongan | `TO` | `target` |
| アゼルバイジャン語 | Azerbaijani | `AZ` | `target` | アルメニア語 | Armenian | `HY` | `target` |
| グルジア語 | Georgian | `KA` | `target` | ヘブライ語 | Hebrew | `HE` | `target` |
| イディッシュ語 | Yiddish | `YI` | `target` | ラディノ語 | Ladino | `LAD` | `target` |
| エスペラント語 | Esperanto | `EO` | `target` | インターリングア語 | Interlingua | `IA` | `target` |
| イド語 | Ido | `IO` | `target` | ヴォラピュク語 | Volapük | `VO` | `target` |
| ロジバン語 | Lojban | `JBO` | `target` | クリンゴン語 | Klingon | `TLH` | `target` |
| トキポナ語 | Toki Pona | `TOK` | `target` | シンディ語 | Sindhi | `SD` | `target` |
| パシュトー語 | Pashto | `PS` | `target` | ダリー語 | Dari | `PRS` | `target` |
| バローチー語 | Balochi | `BAL` | `target` | ブラーフーイー語 | Brahui | `BRH` | `target` |
| サンスクリット語 | Sanskrit | `SA` | `target` | パーリ語 | Pali | `PI` | `target` |
| プラークリット語 | Prakrit | `PRA` | `target` | アヴェスタ語 | Avestan | `AE` | `target` |
| 古代ペルシャ語 | Old Persian | `PEO` | `target` | 古代ギリシャ語 | Ancient Greek | `GRC` | `target` |
| ラテン語 | Latin | `LA` | `target` | 古典中国語 | Classical Chinese | `LZH` | `target` |
| 古代エジプト語 | Ancient Egyptian | `EGY` | `target` | アッカド語 | Akkadian | `AKK` | `target` |
| シュメール語 | Sumerian | `SUX` | `target` | ヒッタイト語 | Hittite | `HIT` | `target` |
| ウラルトゥ語 | Urartian | `URT` | `target` | エラム語 | Elamite | `ELX` | `target` |
| フルリ語 | Hurrian | `HUR` | `target` | ウラル語 | Uralic | `URC` | `target` |
| サモエード語 | Samoyedic | `SYD` | `target` | フィン・ウゴル語 | Finno-Ugric | `FIU` | `target` |
| バルト語派 | Baltic | `BAT` | `target` | スラヴ語派 | Slavic | `SLA` | `target` |
| ゲルマン語派 | Germanic | `GEM` | `target` | ケルト語派 | Celtic | `CEL` | `target` |
| ロマンス語派 | Romance | `ROA` | `target` | インド・イラン語派 | Indo-Iranian | `IRA` | `target` |
| アルタイ諸語 | Altaic | `ALT` | `target` | ドラヴィダ語族 | Dravidian | `DRA` | `target` |
| オーストロネシア語族 | Austronesian | `AUS` | `target` | オーストロアジア語族 | Austroasiatic | `AAS` | `target` |
| タイ・カダイ語族 | Tai-Kadai | `TAI` | `target` | ミャオ・ヤオ語族 | Hmong-Mien | `HMN` | `target` |
| シナ・チベット語族 | Sino-Tibetan | `SIT` | `target` | ニジェール・コンゴ語族 | Niger-Congo | `NIC` | `target` |
| ナイル・サハラ語族 | Nilo-Saharan | `NSD` | `target` | コイサン語族 | Khoisan | `KHO` | `target` |
| エスキモー・アレウト語族 | Eskimo-Aleut | `ESK` | `target` | ナ・デネ語族 | Na-Dene | `NAD` | `target` |
| アメリカ・インディアン諸語 | Amerindian | `AMR` | `target` | パプア諸語 | Papuan | `PAP` | `target` |
| オーストラリア先住民諸語 | Australian Aboriginal | `AUS` | `target` | 人工言語 | Constructed Language | `ART` | `target` |
| 繁体中文 | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>